@@ -2,6 +2,9 @@ from checkov.cloudformation.checks.resource.BaseCloudsplainingIAMCheck import Ba
 
 
 class cloudsplainingCredentialsExposure(BaseCloudsplainingIAMCheck):
+    excluded_actions = {
+        "ecr:GetAuthorizationToken"
+    }
 
     def __init__(self):
         name = "Ensure IAM policies does not allow credentials exposure"
@@ -9,7 +12,11 @@ class cloudsplainingCredentialsExposure(BaseCloudsplainingIAMCheck):
         super().__init__(name=name, id=id)
 
     def cloudsplaining_analysis(self, policy):
-        return policy.credentials_exposure
+        credentials_exposure_actions = policy.credentials_exposure
+        return [
+            x for x in credentials_exposure_actions
+            if x not in cloudsplainingCredentialsExposure.excluded_actions
+        ]
 
 
 check = cloudsplainingCredentialsExposure()
