@@ -20,9 +20,12 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
         self.platform_policy_parser = NXGraphCheckParser()
         self.policies_url = f"{self.bc_integration.api_url}/api/v1/policies/table/data"
 
-    def is_valid(self):
-        return self.bc_integration.is_integration_configured() and not self.bc_integration.skip_policy_download \
-               and not self.integration_feature_failures
+    def is_valid(self) -> bool:
+        return (
+            self.bc_integration.is_integration_configured()
+            and not self.bc_integration.skip_policy_download
+            and not self.integration_feature_failures
+        )
 
     def pre_scan(self):
         try:
