@@ -1,6 +1,7 @@
 import logging
 import platform
 import stat
+import time
 from abc import abstractmethod, ABC
 from pathlib import Path
 from typing import Dict, Any
@@ -50,8 +51,18 @@ class TwistcliIntegration(ABC):
             get_default_post_headers(bc_integration.bc_source, bc_integration.bc_source_version),
             {"Authorization": self.get_bc_api_key()},
         )
-        response = requests.request("POST", f"{self.vulnerabilities_base_url}/report", headers=headers, json=payload)
-        response.raise_for_status()
+
+        for i in range(2):
+            response = requests.request("POST", f"{self.vulnerabilities_base_url}/report", headers=headers, json=payload)
+            try:
+                response.raise_for_status()
+                break
+            except requests.exceptions.HTTPError as ex:
+                logging.error(f"HTTP error on request {self.vulnerabilities_base_url}/report, payload:\n{payload}")
+                if ex.response.status_code >= 500 and i != 1:
+                    time.sleep(2)
+                    continue
+                raise ex
 
     async def report_results_async(
         self,
