@@ -11,4 +11,7 @@ class LessThanOrEqualAttributeSolver(GreaterThanAttributeSolver):
         super().__init__(resource_types=resource_types, attribute=attribute, value=value)
 
     def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:
+        if vertex.get(attribute) is None:
+            return False
+
         return not super()._get_operation(vertex, attribute)
