@@ -1,14 +1,15 @@
+from pathlib import Path
+from typing import List, Dict, Any, Tuple
+
 import yaml
 from yaml.loader import SafeLoader
 
-def loads(filename):
+def loads(content: str) -> List[Dict[str, Any]]:
     """
     Load the given YAML string
     """
-    template = None
-    with open(filename, 'r') as stream:
 
-        template = list(yaml.load_all(stream, Loader=SafeLineLoader))
+    template = list(yaml.load_all(content, Loader=SafeLineLoader))
 
     # Convert an empty file to an empty dict
     if template is None:
@@ -17,20 +18,20 @@ def loads(filename):
     return template
 
 
-def load(filename):
+def load(filename: Path) -> Tuple[List[Dict[str, Any]], List[Tuple[int, str]]]:
     """
     Load the given YAML file
     """
 
-    content = ''
+    file_path = filename if isinstance(filename, Path) else Path(filename)
+    content = file_path.read_text()
 
-    with open(filename) as fp:
-        content = fp.read()
-        fp.seek(0)
-        file_lines = [(ind + 1, line) for (ind, line) in
-                      list(enumerate(fp.readlines()))]
+    if not all(key in content for key in ("apiVersion", "kind")):
+        return [{}], []
 
-    template = loads(filename)
+    file_lines = [(idx + 1, line) for idx, line in enumerate(content.splitlines(keepends=True))]
+
+    template = loads(content)
 
     return (template, file_lines)
 
