@@ -2,10 +2,14 @@ import logging
 import operator
 import os
 from functools import reduce
+from typing import Type, Optional, List
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
+from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder import CustomAttributes
+from checkov.common.graph.graph_builder.local_graph import LocalGraph
+from checkov.common.graph.graph_manager import GraphManager
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report, merge_reports
 from checkov.common.runners.base_runner import BaseRunner
@@ -19,12 +23,12 @@ from checkov.runner_filter import RunnerFilter
 class Runner(BaseRunner):
     def __init__(
         self,
-        graph_class=KubernetesLocalGraph,
-        db_connector=NetworkxConnector(),
-        source="Kubernetes",
-        graph_manager=None,
-        external_registries=None
-    ):
+        graph_class: Type[LocalGraph] = KubernetesLocalGraph,
+        db_connector: NetworkxConnector = NetworkxConnector(),
+        source: str = "Kubernetes",
+        graph_manager: Optional[GraphManager] = None,
+        external_registries: Optional[List[BaseRegistry]] = None
+    ) -> None:
         self.external_registries = [] if external_registries is None else external_registries
         self.check_type = "kubernetes"
         self.graph_class = graph_class
@@ -68,6 +72,7 @@ class Runner(BaseRunner):
             # If -d is used, root_folder will be the value given, and -f will start with a / (hardcoded above).
             # The goal here is simply to get a valid path to the file (which sls_file does not always give).
             file_abs_path = _get_entity_abs_path(root_folder, k8_file)
+            k8_file_path = f"/{os.path.relpath(file_abs_path, root_folder)}"
             # Run for each definition
             for entity_conf in self.definitions[k8_file]:
                 entity_type = entity_conf.get("kind")
@@ -88,7 +93,7 @@ class Runner(BaseRunner):
 
                     record = Record(
                         check_id=check.id, bc_check_id=check.bc_id, check_name=check.name,
-                        check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file,
+                        check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file_path,
                         file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
                         resource=resource_id, evaluations=variable_evaluations,
                         check_class=check.__class__.__module__, file_abs_path=file_abs_path)
@@ -127,7 +132,7 @@ class Runner(BaseRunner):
 
 
 def _get_entity_abs_path(root_folder, entity_file_path):
-    if entity_file_path[0] == '/':
+    if entity_file_path[0] == '/' and (root_folder and not entity_file_path.startswith(root_folder)):
         path_to_convert = (root_folder + entity_file_path) if root_folder else entity_file_path
     else:
         path_to_convert = (os.path.join(root_folder, entity_file_path)) if root_folder else entity_file_path
