@@ -3,6 +3,7 @@ import json
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.common.util.type_forcers import is_json
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+from typing import List, Any
 
 
 class ECRPolicy(BaseResourceCheck):
@@ -20,11 +21,13 @@ class ECRPolicy(BaseResourceCheck):
         :param conf: aws_ecr_repository configuration
         :return: <CheckResult>
         """
-        if "policy" in conf.keys():
-            if is_json(conf["policy"][0]):
-                if json.loads(conf["policy"][0])['Statement'][0]['Principal'] == '*':
-                    return CheckResult.FAILED
+        if "policy" in conf.keys() and is_json(conf["policy"][0]) \
+                and json.loads(conf["policy"][0])['Statement'][0]['Principal'] == '*':
+            return CheckResult.FAILED
         return CheckResult.PASSED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['policy']
+
 
 check = ECRPolicy()
